"""
Synchronise users to GSuite

Usage:
    gsuitesync (-h | --help)
    gsuitesync [--configuration=FILE] [--quiet] [--really-do-this]

Options:
    -h, --help                  Show a brief usage summary.

    --quiet                     Reduce logging verbosity.

    --configuration=FILE        Specify configuration file to load.

    --really-do-this            Actually try to make the changes.

"""
import logging
import os
import sys

import docopt

from . import config
from . import sync


LOG = logging.getLogger(os.path.basename(sys.argv[0]))


def main():
    opts = docopt.docopt(__doc__)

    # Configure logging
    logging.basicConfig(level=logging.WARN if opts['--quiet'] else logging.INFO)

    # HACK: make the googleapiclient.discovery module less spammy in the logs
    logging.getLogger('googleapiclient.discovery').setLevel(logging.WARN)
    logging.getLogger('googleapiclient.discovery_cache').setLevel(logging.ERROR)

    LOG.info('Loading configuration')
    configuration = config.load_configuration(opts['--configuration'])

    # Perform sync
    sync.sync(configuration, read_only=not opts['--really-do-this'])
