"""
Google API authentication.

"""
import dataclasses
import logging
import typing

from google.oauth2 import service_account

from .config import ConfigurationDataclassMixin


LOG = logging.getLogger(__name__)


@dataclasses.dataclass
class Configuration(ConfigurationDataclassMixin):
    """
    Configuration of Google API access credentials.

    """
    # Path to on-disk JSON credentials used when accessing the API.
    credentials: str

    # Path to on-disk JSON credentials used when accessing the API in "read-only" mode. Use this if
    # you want to have a separate "safe" service account which can only read data. If null, use the
    # same credentials for reading and writing.
    read_only_credentials: typing.Union[str, None] = None

    def load_credentials(self, *, read_only=True):
        """
        Create a Google credentials object from the configuration. Use *read_only* to indicate if
        read-only credentials are preferred.

        """
        credentials = self.credentials
        if read_only and self.read_only_credentials is not None:
            credentials = self.read_only_credentials
            LOG.info('Using read-only credentials.')

        LOG.info('Loading Google account credentials from "%s"', credentials)
        return service_account.Credentials.from_service_account_file(credentials)
